/**
 * (C) Copyright IBM Corp. 2023.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/// <reference types="node" />
import { IncomingHttpHeaders, OutgoingHttpHeaders } from 'http';
import { BaseService, UserOptions } from 'ibm-cloud-sdk-core';
/**
 * Management interface of Vulnerability Advisor for IBM Cloud Container Registry
 *
 * API Version: 4.0.0
 */
declare class VulnerabilityAdvisorV4 extends BaseService {
    static DEFAULT_SERVICE_URL: string;
    static DEFAULT_SERVICE_NAME: string;
    private static _regionalEndpoints;
    /**
     * Returns the service URL associated with the specified region.
     * @param region a string representing the region
     * @returns the service URL associated with the specified region or undefined
     * if no mapping for the region exists
     */
    static getServiceUrlForRegion(region: string): string;
    /*************************
     * Factory method
     ************************/
    /**
     * Constructs an instance of VulnerabilityAdvisorV4 with passed in options and external configuration.
     *
     * @param {UserOptions} [options] - The parameters to send to the service.
     * @param {string} [options.serviceName] - The name of the service to configure
     * @param {Authenticator} [options.authenticator] - The Authenticator object used to authenticate requests to the service
     * @param {string} [options.serviceUrl] - The URL for the service
     * @returns {VulnerabilityAdvisorV4}
     */
    static newInstance(options: UserOptions): VulnerabilityAdvisorV4;
    /** The preferred language code for this request. */
    acceptLanguage?: string;
    /** The unique ID for your IBM Cloud account. Run 'ibmcloud cr info' to get the ID of the target account. */
    account: string;
    /**
     * Construct a VulnerabilityAdvisorV4 object.
     *
     * @param {Object} options - Options for the service.
     * @param {string} [options.acceptLanguage] - The preferred language code for this request.
     * @param {string} options.account - The unique ID for your IBM Cloud account. Run 'ibmcloud cr info' to get the ID of
     * the target account.
     * @param {string} [options.serviceUrl] - The base url to use when contacting the service. The base url may differ between IBM Cloud regions.
     * @param {OutgoingHttpHeaders} [options.headers] - Default headers that shall be included with every request to the service.
     * @param {Authenticator} options.authenticator - The Authenticator object used to authenticate requests to the service
     * @constructor
     * @returns {VulnerabilityAdvisorV4}
     */
    constructor(options: UserOptions);
    /*************************
     * report
     ************************/
    /**
     * Get the vulnerability assessment for all images.
     *
     * Get the vulnerability assessment for the list of registry images that belong to a specific account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {string} [params.repository] - The name of the repository that you want to see image vulnerability
     * assessments for. For example, us.icr.io/namespace/image.
     * @param {string} [params.includeIbm] - When set to true, the returned list contains IBM public images and the
     * account images. If not set, or set to false, the list contains only the account images.
     * @param {string} [params.includePrivate] - When set to false, the returned list does not contain the private account
     * images. If not set, or set to true, the list contains the private account images.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanReportList>>}
     */
    accountReportQueryPath(params?: VulnerabilityAdvisorV4.AccountReportQueryPathParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanReportList>>;
    /**
     * Get vulnerability assessment status for all images.
     *
     * Get the vulnerability assessment status for the list of registry images that belong to a specific account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {string} [params.repository] - The name of the repository that you want to see image vulnerability
     * assessments for. For example, us.icr.io/namespace/image.
     * @param {string} [params.includeIbm] - When set to true, the returned list contains IBM public images and the
     * account images. If not set, or set to false, the list contains only the account images.
     * @param {string} [params.includePrivate] - When set to false, the returned list does not contain the private account
     * images. If not set, or set to true, the list contains the private account images.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanreportImageSummaryList>>}
     */
    accountStatusQueryPath(params?: VulnerabilityAdvisorV4.AccountStatusQueryPathParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanreportImageSummaryList>>;
    /**
     * Get vulnerability assessment.
     *
     * Get the vulnerability assessment for a registry image.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.name - The name of the image. For example, us.icr.io/namespace/repository:tag.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanReport>>}
     */
    imageReportQueryPath(params: VulnerabilityAdvisorV4.ImageReportQueryPathParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanReport>>;
    /**
     * Get vulnerability assessment status.
     *
     * Get the overall vulnerability status for a registry image.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.name - The name of the image. For example, us.icr.io/namespace/repository:tag.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanreportSummary>>}
     */
    imageStatusQueryPath(params: VulnerabilityAdvisorV4.ImageStatusQueryPathParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanreportSummary>>;
    /*************************
     * exemption
     ************************/
    /**
     * List account level exemptions.
     *
     * List the exemptions that are specified with account level scope.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>}
     */
    listExemptionAccount(params?: VulnerabilityAdvisorV4.ListExemptionAccountParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>;
    /**
     * Get an account level exemption.
     *
     * Get details of an exemption that is specified with account level scope.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>}
     */
    getExemptionAccount(params: VulnerabilityAdvisorV4.GetExemptionAccountParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>;
    /**
     * Create or update an account level exemption.
     *
     * Create or update an exemption that is specified with account level scope.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>}
     */
    createExemptionAccount(params: VulnerabilityAdvisorV4.CreateExemptionAccountParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>;
    /**
     * Delete an account level exemption.
     *
     * Delete an exemption that is specified with account level scope.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.EmptyObject>>}
     */
    deleteExemptionAccount(params: VulnerabilityAdvisorV4.DeleteExemptionAccountParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.EmptyObject>>;
    /**
     * List resource exemptions.
     *
     * List the exemptions that are specified for a resource (account, registry namespace, repository, or image).
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>}
     */
    listExemptionResource(params: VulnerabilityAdvisorV4.ListExemptionResourceParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>;
    /**
     * Get details of a resource exemption.
     *
     * Get an exemption that is specified for a resource (account, registry namespace, repository, or image).
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>}
     */
    getExemptionResource(params: VulnerabilityAdvisorV4.GetExemptionResourceParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>;
    /**
     * Create or update a resource exemption.
     *
     * Create or update an exemption that is specified for a resource (account, registry namespace, repository, or image).
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>}
     */
    createExemptionResource(params: VulnerabilityAdvisorV4.CreateExemptionResourceParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>;
    /**
     * Delete a resource exemption.
     *
     * Delete an exemption that is specified for a resource (account, registry namespace, repository, or image).
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.EmptyObject>>}
     */
    deleteExemptionResource(params: VulnerabilityAdvisorV4.DeleteExemptionResourceParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.EmptyObject>>;
    /**
     * List the types of exemption.
     *
     * List the types of exemption.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ExemptionTypeInfo[]>>}
     */
    exemptHandler(params?: VulnerabilityAdvisorV4.ExemptHandlerParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ExemptionTypeInfo[]>>;
    /**
     * List all exemptions.
     *
     * List all of the exemptions in the given account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>}
     */
    listAccountExemptions(params?: VulnerabilityAdvisorV4.ListAccountExemptionsParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>;
    /**
     * Delete all exemptions.
     *
     * Delete all of the exemptions in the given account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ExemptionDeletionInfo>>}
     */
    exemptionsAccountDeleteHandler(params?: VulnerabilityAdvisorV4.ExemptionsAccountDeleteHandlerParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ExemptionDeletionInfo>>;
    /**
     * List image exemptions.
     *
     * List all of the exemptions for an image.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {boolean} [params.includeScope] - Include scope on returned exemptions.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>}
     */
    listImageExemptions(params: VulnerabilityAdvisorV4.ListImageExemptionsParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>;
    /**
     * List exemptions for images.
     *
     * List the exemptions for the given list of images.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string[]} params.body - List of images.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.JsonObject>>}
     */
    listBulkImageExemptions(params: VulnerabilityAdvisorV4.ListBulkImageExemptionsParams): Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.JsonObject>>;
}
/*************************
 * interfaces
 ************************/
declare namespace VulnerabilityAdvisorV4 {
    /** Options for the `VulnerabilityAdvisorV4` constructor. */
    interface Options extends UserOptions {
        /** The preferred language code for this request. */
        acceptLanguage?: string;
        /** The unique ID for your IBM Cloud account. Run 'ibmcloud cr info' to get the ID of the target account. */
        account: string;
    }
    /** An operation response. */
    interface Response<T = any> {
        result: T;
        status: number;
        statusText: string;
        headers: IncomingHttpHeaders;
    }
    /** The callback for a service request. */
    type Callback<T> = (error: any, response?: Response<T>) => void;
    /** The body of a service request that returns no response data. */
    interface EmptyObject {
    }
    /** A standard JS object, defined to avoid the limitations of `Object` and `object` */
    interface JsonObject {
        [key: string]: any;
    }
    /*************************
     * request interfaces
     ************************/
    /** Parameters for the `accountReportQueryPath` operation. */
    interface AccountReportQueryPathParams {
        /** The name of the repository that you want to see image vulnerability assessments for. For example,
         *  us.icr.io/namespace/image.
         */
        repository?: string;
        /** When set to true, the returned list contains IBM public images and the account images. If not set, or set to
         *  false, the list contains only the account images.
         */
        includeIbm?: string;
        /** When set to false, the returned list does not contain the private account images. If not set, or set to
         *  true, the list contains the private account images.
         */
        includePrivate?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `accountStatusQueryPath` operation. */
    interface AccountStatusQueryPathParams {
        /** The name of the repository that you want to see image vulnerability assessments for. For example,
         *  us.icr.io/namespace/image.
         */
        repository?: string;
        /** When set to true, the returned list contains IBM public images and the account images. If not set, or set to
         *  false, the list contains only the account images.
         */
        includeIbm?: string;
        /** When set to false, the returned list does not contain the private account images. If not set, or set to
         *  true, the list contains the private account images.
         */
        includePrivate?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `imageReportQueryPath` operation. */
    interface ImageReportQueryPathParams {
        /** The name of the image. For example, us.icr.io/namespace/repository:tag. */
        name: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `imageStatusQueryPath` operation. */
    interface ImageStatusQueryPathParams {
        /** The name of the image. For example, us.icr.io/namespace/repository:tag. */
        name: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listExemptionAccount` operation. */
    interface ListExemptionAccountParams {
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getExemptionAccount` operation. */
    interface GetExemptionAccountParams {
        /** Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See /va/api/v4/exempt/types for more details. */
        issueType: string;
        /** Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details. */
        issueId: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createExemptionAccount` operation. */
    interface CreateExemptionAccountParams {
        /** Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See /va/api/v4/exempt/types for more details. */
        issueType: string;
        /** Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details. */
        issueId: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteExemptionAccount` operation. */
    interface DeleteExemptionAccountParams {
        /** Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See /va/api/v4/exempt/types for more details. */
        issueType: string;
        /** Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details. */
        issueId: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listExemptionResource` operation. */
    interface ListExemptionResourceParams {
        /** IBM Cloud Registry resource (namespace, namespace/repository, namespace/repository:tag, or
         *  namespace/repository@sha256:hash).
         */
        resource: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getExemptionResource` operation. */
    interface GetExemptionResourceParams {
        /** IBM Cloud Registry resource (namespace, namespace/repository, namespace/repository:tag, or
         *  namespace/repository@sha256:hash).
         */
        resource: string;
        /** Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See /va/api/v4/exempt/types for more details. */
        issueType: string;
        /** Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details. */
        issueId: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createExemptionResource` operation. */
    interface CreateExemptionResourceParams {
        /** IBM Cloud Registry resource (namespace, namespace/repository, namespace/repository:tag, or
         *  namespace/repository@sha256:hash).
         */
        resource: string;
        /** Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See /va/api/v4/exempt/types for more details. */
        issueType: string;
        /** Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details. */
        issueId: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteExemptionResource` operation. */
    interface DeleteExemptionResourceParams {
        /** IBM Cloud Registry resource (namespace, namespace/repository, namespace/repository:tag, or
         *  namespace/repository@sha256:hash).
         */
        resource: string;
        /** Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See /va/api/v4/exempt/types for more details. */
        issueType: string;
        /** Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details. */
        issueId: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `exemptHandler` operation. */
    interface ExemptHandlerParams {
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listAccountExemptions` operation. */
    interface ListAccountExemptionsParams {
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `exemptionsAccountDeleteHandler` operation. */
    interface ExemptionsAccountDeleteHandlerParams {
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listImageExemptions` operation. */
    interface ListImageExemptionsParams {
        /** IBM Cloud Registry resource (namespace, namespace/repository, namespace/repository:tag, or
         *  namespace/repository@sha256:hash).
         */
        resource: string;
        /** Include scope on returned exemptions. */
        includeScope?: boolean;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listBulkImageExemptions` operation. */
    interface ListBulkImageExemptionsParams {
        /** List of images. */
        body: string[];
        headers?: OutgoingHttpHeaders;
    }
    /*************************
     * model interfaces
     ************************/
    /** Exemption. */
    interface Exemption {
        /** The unique ID for the IBM Cloud account for this policy. */
        account_id: string;
        /** ID of issue being exempted. */
        issue_id: string;
        /** Type of issue being exempted. */
        issue_type: string;
        scope?: ExemptionScope;
    }
    /** ExemptionScope. */
    interface ExemptionScope {
        /** The type of scope the exemption applies to: account, namespace, repository, image. */
        scope_type: string;
        /** The IBM Cloud Registry namespace included in scope. */
        namespace?: string;
        /** The IBM Cloud Registry repository included in scope. */
        repository?: string;
        /** The IBM Cloud Registry tag included in scope. */
        tag?: string;
    }
    /** ScanReport. */
    interface ScanReport {
        /** Not supported, will always be empty. */
        configuration_issues: ScanresultConfigurationIssue[];
        /** The unique ID of the report. */
        id: string;
        /** The primary operating system distribution identified in the container image. */
        os_distribution: ScanReportOsDistribution;
        /** The last time that the vulnerability data source was checked for vulnerabilities as a UNIX timestamp. */
        scan_time: number;
        /** Overall vulnerability assessment status: OK, WARN, FAIL, UNSUPPORTED, INCOMPLETE, UNSCANNED. For more
         *  information about these status codes, see
         *  https://{DomainName}/apidocs/container-registry/va#getting-started-vulnerability-report-status-codes.
         */
        status: string;
        /** Vulnerabilities found in the container image at the scan time. */
        vulnerabilities: ScanresultCVE[];
    }
    /** ScanReportList. */
    interface ScanReportList {
        /** A dictionary of image names as key and report.Report object as value. */
        assessments: JsonObject;
    }
    /** The primary operating system distribution identified in the container image. */
    interface ScanReportOsDistribution {
        /** Primary operating system distribution. */
        distribution_id?: string;
        /** Primary operating system version. */
        version_id?: string;
        /** Primary operating system version code name. */
        version_code_name?: string;
    }
    /** ExemptionDeletionInfo. */
    interface ExemptionDeletionInfo {
        number_of_exemptions_deleted: number;
    }
    /** ExemptionTypeInfo. */
    interface ExemptionTypeInfo {
        display_name: string;
        identifier: string;
        translationKey?: string;
        validation_regex: string;
    }
    /** ScanreportImageSummary. */
    interface ScanreportImageSummary {
        /** Not supported, this will always be zero. */
        configuration_issue_count: number;
        /** The image creation time as a UNIX timestamp. */
        created_time: number;
        /** Not supported, this will always be zero. */
        exempt_configuration_issue_count: number;
        /** The number of exempt issues found. */
        exempt_issue_count: number;
        /** The number of exempt vulnerability issues found. */
        exempt_vulnerability_count: number;
        /** The number of issues found. */
        issue_count: number;
        /** Full docker image name including tag e.g. us.icr.io/namespace/repository:tag. */
        name: string;
        /** The last time that the vulnerability data source was checked for vulnerabilities as a UNIX timestamp. */
        scan_time: number;
        /** Overall vulnerability assessment status: OK, WARN, FAIL, UNSUPPORTED, INCOMPLETE, UNSCANNED. For more
         *  information about these status codes, see
         *  https://{DomainName}/apidocs/container-registry/va#getting-started-vulnerability-report-status-codes.
         */
        status: string;
        /** The number of vulnerability issues found. */
        vulnerability_count: number;
    }
    /** ScanreportImageSummaryList. */
    interface ScanreportImageSummaryList {
        /** List of image summaries. */
        images: ScanreportImageSummary[];
    }
    /** ScanreportSummary. */
    interface ScanreportSummary {
        /** Not supported, this will always be zero. */
        configuration_issue_count: number;
        /** Not supported, this will always be zero. */
        exempt_configuration_issue_count: number;
        /** The number of exempt issues found. */
        exempt_issue_count: number;
        /** The number of exempt vulnerability issues found. */
        exempt_vulnerability_count: number;
        /** The number of issues found. */
        issue_count: number;
        /** The last time that the vulnerability data source was checked for vulnerabilities as a UNIX timestamp. */
        scan_time: number;
        /** Overall vulnerability assessment status: OK, WARN, FAIL, UNSUPPORTED, INCOMPLETE, UNSCANNED. For more
         *  information about these status codes, see
         *  https://{DomainName}/apidocs/container-registry/va#getting-started-vulnerability-report-status-codes.
         */
        status: string;
        /** The number of vulnerability issues found. */
        vulnerability_count: number;
    }
    /** ScanresultCVE. */
    interface ScanresultCVE {
        /** True if this CVE has been exempted by user policy, and false otherwise. */
        cve_exempt: boolean;
        /** The ID for this CVE. */
        cve_id: string;
        /** Number of security notices that contain fixes for this CVE and are exempted by user policy. */
        exempt_security_notice_count: number;
        /** 'exempt' if this CVE is exempt or all security notices for this CVE are exempt. 'partial' if this CVE is not
         *  exempt but a subset of security notices for this CVE are exempt. 'active' if this CVE is not exempt and no
         *  security notices for this CVE are exempt.
         */
        exempt_status: string;
        /** Number of security notices that contain fixes for this CVE and are not exempted by user policy. */
        security_notice_count: number;
        /** Security notices that contain fixes for this CVE. */
        security_notices: ScanresultSecurityNotice[];
        /** The summary of the security vulnerability for this CVE. */
        summary: string;
        /** Total number of security notices that contain fixes for this CVE. */
        total_security_notice_count: number;
    }
    /** ScanresultConfigurationIssue. */
    interface ScanresultConfigurationIssue {
        /** Not supported. */
        corrective_action: string;
        /** Not supported. */
        description: string;
        /** Not supported. */
        exempt: boolean;
        /** Not supported. */
        meta: JsonObject;
        /** Not supported. */
        type: string;
    }
    /** ScanresultPackageFixes. */
    interface ScanresultPackageFixes {
        /** Advice on how to solve this vulnerability. */
        corrective_action: string;
        /** Description of the vulnerability. */
        description: string;
        /** The version of this package that contains the fix for this vulnerability. */
        fix_version: string;
        /** The version of this package that was found installed at scan time. */
        installed_version: string;
        /** The name of the package. */
        package_name: string;
    }
    /** ScanresultSecurityNotice. */
    interface ScanresultSecurityNotice {
        /** Further information about this security notice. */
        notice: string;
        /** True if this security notice has been exempted by user policy, and false otherwise. */
        notice_exempt: boolean;
        /** The ID for this security notice. */
        notice_id: string;
        /** Summary of information about the security vulnerabilities fixed by this security notice. */
        summary: string;
        /** Package updates that contain fixes for this vulnerability. */
        vulnerable_packages: ScanresultPackageFixes[];
    }
}
export = VulnerabilityAdvisorV4;
