"use strict";
/**
 * (C) Copyright IBM Corp. 2023.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
/**
 * IBM OpenAPI SDK Code Generator Version: 3.73.0-eeee85a9-20230607-165104
 */
var extend = require("extend");
var ibm_cloud_sdk_core_1 = require("ibm-cloud-sdk-core");
var common_1 = require("../lib/common");
/**
 * Management interface of Vulnerability Advisor for IBM Cloud Container Registry
 *
 * API Version: 4.0.0
 */
var VulnerabilityAdvisorV4 = /** @class */ (function (_super) {
    __extends(VulnerabilityAdvisorV4, _super);
    /**
     * Construct a VulnerabilityAdvisorV4 object.
     *
     * @param {Object} options - Options for the service.
     * @param {string} [options.acceptLanguage] - The preferred language code for this request.
     * @param {string} options.account - The unique ID for your IBM Cloud account. Run 'ibmcloud cr info' to get the ID of
     * the target account.
     * @param {string} [options.serviceUrl] - The base url to use when contacting the service. The base url may differ between IBM Cloud regions.
     * @param {OutgoingHttpHeaders} [options.headers] - Default headers that shall be included with every request to the service.
     * @param {Authenticator} options.authenticator - The Authenticator object used to authenticate requests to the service
     * @constructor
     * @returns {VulnerabilityAdvisorV4}
     */
    function VulnerabilityAdvisorV4(options) {
        var _this = this;
        options = options || {};
        var _requiredParams = ['account'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(options, _requiredParams, null);
        if (_validationErrors) {
            throw _validationErrors;
        }
        _this = _super.call(this, options) || this;
        if (options.serviceUrl) {
            _this.setServiceUrl(options.serviceUrl);
        }
        else {
            _this.setServiceUrl(VulnerabilityAdvisorV4.DEFAULT_SERVICE_URL);
        }
        _this.acceptLanguage = options.acceptLanguage;
        _this.account = options.account;
        return _this;
    }
    /**
     * Returns the service URL associated with the specified region.
     * @param region a string representing the region
     * @returns the service URL associated with the specified region or undefined
     * if no mapping for the region exists
     */
    VulnerabilityAdvisorV4.getServiceUrlForRegion = function (region) {
        return this._regionalEndpoints.get(region);
    };
    /*************************
     * Factory method
     ************************/
    /**
     * Constructs an instance of VulnerabilityAdvisorV4 with passed in options and external configuration.
     *
     * @param {UserOptions} [options] - The parameters to send to the service.
     * @param {string} [options.serviceName] - The name of the service to configure
     * @param {Authenticator} [options.authenticator] - The Authenticator object used to authenticate requests to the service
     * @param {string} [options.serviceUrl] - The URL for the service
     * @returns {VulnerabilityAdvisorV4}
     */
    VulnerabilityAdvisorV4.newInstance = function (options) {
        options = options || {};
        if (!options.serviceName) {
            options.serviceName = this.DEFAULT_SERVICE_NAME;
        }
        if (!options.authenticator) {
            options.authenticator = (0, ibm_cloud_sdk_core_1.getAuthenticatorFromEnvironment)(options.serviceName);
        }
        var service = new VulnerabilityAdvisorV4(options);
        service.configureService(options.serviceName);
        if (options.serviceUrl) {
            service.setServiceUrl(options.serviceUrl);
        }
        return service;
    };
    /*************************
     * report
     ************************/
    /**
     * Get the vulnerability assessment for all images.
     *
     * Get the vulnerability assessment for the list of registry images that belong to a specific account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {string} [params.repository] - The name of the repository that you want to see image vulnerability
     * assessments for. For example, us.icr.io/namespace/image.
     * @param {string} [params.includeIbm] - When set to true, the returned list contains IBM public images and the
     * account images. If not set, or set to false, the list contains only the account images.
     * @param {string} [params.includePrivate] - When set to false, the returned list does not contain the private account
     * images. If not set, or set to true, the list contains the private account images.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanReportList>>}
     */
    VulnerabilityAdvisorV4.prototype.accountReportQueryPath = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = [];
        var _validParams = ['repository', 'includeIbm', 'includePrivate', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var query = {
            'repository': _params.repository,
            'includeIBM': _params.includeIbm,
            'includePrivate': _params.includePrivate,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'accountReportQueryPath');
        var parameters = {
            options: {
                url: '/va/api/v4/report/account',
                method: 'GET',
                qs: query,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Get vulnerability assessment status for all images.
     *
     * Get the vulnerability assessment status for the list of registry images that belong to a specific account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {string} [params.repository] - The name of the repository that you want to see image vulnerability
     * assessments for. For example, us.icr.io/namespace/image.
     * @param {string} [params.includeIbm] - When set to true, the returned list contains IBM public images and the
     * account images. If not set, or set to false, the list contains only the account images.
     * @param {string} [params.includePrivate] - When set to false, the returned list does not contain the private account
     * images. If not set, or set to true, the list contains the private account images.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanreportImageSummaryList>>}
     */
    VulnerabilityAdvisorV4.prototype.accountStatusQueryPath = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = [];
        var _validParams = ['repository', 'includeIbm', 'includePrivate', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var query = {
            'repository': _params.repository,
            'includeIBM': _params.includeIbm,
            'includePrivate': _params.includePrivate,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'accountStatusQueryPath');
        var parameters = {
            options: {
                url: '/va/api/v4/report/account/status',
                method: 'GET',
                qs: query,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Get vulnerability assessment.
     *
     * Get the vulnerability assessment for a registry image.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.name - The name of the image. For example, us.icr.io/namespace/repository:tag.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanReport>>}
     */
    VulnerabilityAdvisorV4.prototype.imageReportQueryPath = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['name'];
        var _validParams = ['name', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var path = {
            'name': _params.name,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'imageReportQueryPath');
        var parameters = {
            options: {
                url: '/va/api/v4/report/image/{name}',
                method: 'GET',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Get vulnerability assessment status.
     *
     * Get the overall vulnerability status for a registry image.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.name - The name of the image. For example, us.icr.io/namespace/repository:tag.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ScanreportSummary>>}
     */
    VulnerabilityAdvisorV4.prototype.imageStatusQueryPath = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['name'];
        var _validParams = ['name', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var path = {
            'name': _params.name,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'imageStatusQueryPath');
        var parameters = {
            options: {
                url: '/va/api/v4/report/image/status/{name}',
                method: 'GET',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /*************************
     * exemption
     ************************/
    /**
     * List account level exemptions.
     *
     * List the exemptions that are specified with account level scope.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>}
     */
    VulnerabilityAdvisorV4.prototype.listExemptionAccount = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = [];
        var _validParams = ['headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'listExemptionAccount');
        var parameters = {
            options: {
                url: '/va/api/v4/exempt/image',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Get an account level exemption.
     *
     * Get details of an exemption that is specified with account level scope.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>}
     */
    VulnerabilityAdvisorV4.prototype.getExemptionAccount = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['issueType', 'issueId'];
        var _validParams = ['issueType', 'issueId', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var path = {
            'issueType': _params.issueType,
            'issueID': _params.issueId,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'getExemptionAccount');
        var parameters = {
            options: {
                url: '/va/api/v4/exempt/image/issue/{issueType}/{issueID}',
                method: 'GET',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Create or update an account level exemption.
     *
     * Create or update an exemption that is specified with account level scope.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>}
     */
    VulnerabilityAdvisorV4.prototype.createExemptionAccount = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['issueType', 'issueId'];
        var _validParams = ['issueType', 'issueId', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var path = {
            'issueType': _params.issueType,
            'issueID': _params.issueId,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'createExemptionAccount');
        var parameters = {
            options: {
                url: '/va/api/v4/exempt/image/issue/{issueType}/{issueID}',
                method: 'POST',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Delete an account level exemption.
     *
     * Delete an exemption that is specified with account level scope.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.EmptyObject>>}
     */
    VulnerabilityAdvisorV4.prototype.deleteExemptionAccount = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['issueType', 'issueId'];
        var _validParams = ['issueType', 'issueId', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var path = {
            'issueType': _params.issueType,
            'issueID': _params.issueId,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'deleteExemptionAccount');
        var parameters = {
            options: {
                url: '/va/api/v4/exempt/image/issue/{issueType}/{issueID}',
                method: 'DELETE',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * List resource exemptions.
     *
     * List the exemptions that are specified for a resource (account, registry namespace, repository, or image).
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>}
     */
    VulnerabilityAdvisorV4.prototype.listExemptionResource = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['resource'];
        var _validParams = ['resource', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var path = {
            'resource': _params.resource,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'listExemptionResource');
        var parameters = {
            options: {
                url: '/va/api/v4/exempt/image/{resource}',
                method: 'GET',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Get details of a resource exemption.
     *
     * Get an exemption that is specified for a resource (account, registry namespace, repository, or image).
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>}
     */
    VulnerabilityAdvisorV4.prototype.getExemptionResource = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['resource', 'issueType', 'issueId'];
        var _validParams = ['resource', 'issueType', 'issueId', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var path = {
            'resource': _params.resource,
            'issueType': _params.issueType,
            'issueID': _params.issueId,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'getExemptionResource');
        var parameters = {
            options: {
                url: '/va/api/v4/exempt/image/{resource}/issue/{issueType}/{issueID}',
                method: 'GET',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Create or update a resource exemption.
     *
     * Create or update an exemption that is specified for a resource (account, registry namespace, repository, or image).
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption>>}
     */
    VulnerabilityAdvisorV4.prototype.createExemptionResource = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['resource', 'issueType', 'issueId'];
        var _validParams = ['resource', 'issueType', 'issueId', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var path = {
            'resource': _params.resource,
            'issueType': _params.issueType,
            'issueID': _params.issueId,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'createExemptionResource');
        var parameters = {
            options: {
                url: '/va/api/v4/exempt/image/{resource}/issue/{issueType}/{issueID}',
                method: 'POST',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Delete a resource exemption.
     *
     * Delete an exemption that is specified for a resource (account, registry namespace, repository, or image).
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {string} params.issueType - Exemption type, e.g. 'cve' or 'sn' or 'configuration'. See
     * /va/api/v4/exempt/types for more details.
     * @param {string} params.issueId - Exemption ID, e.g. 'CVE-2018-9999'. See /va/api/v4/exempt/types for more details.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.EmptyObject>>}
     */
    VulnerabilityAdvisorV4.prototype.deleteExemptionResource = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['resource', 'issueType', 'issueId'];
        var _validParams = ['resource', 'issueType', 'issueId', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var path = {
            'resource': _params.resource,
            'issueType': _params.issueType,
            'issueID': _params.issueId,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'deleteExemptionResource');
        var parameters = {
            options: {
                url: '/va/api/v4/exempt/image/{resource}/issue/{issueType}/{issueID}',
                method: 'DELETE',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * List the types of exemption.
     *
     * List the types of exemption.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ExemptionTypeInfo[]>>}
     */
    VulnerabilityAdvisorV4.prototype.exemptHandler = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = [];
        var _validParams = ['headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'exemptHandler');
        var parameters = {
            options: {
                url: '/va/api/v4/exempt/types',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * List all exemptions.
     *
     * List all of the exemptions in the given account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>}
     */
    VulnerabilityAdvisorV4.prototype.listAccountExemptions = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = [];
        var _validParams = ['headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'listAccountExemptions');
        var parameters = {
            options: {
                url: '/va/api/v4/exemptions/account',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * Delete all exemptions.
     *
     * Delete all of the exemptions in the given account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.ExemptionDeletionInfo>>}
     */
    VulnerabilityAdvisorV4.prototype.exemptionsAccountDeleteHandler = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = [];
        var _validParams = ['headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'exemptionsAccountDeleteHandler');
        var parameters = {
            options: {
                url: '/va/api/v4/exemptions/deleteAll',
                method: 'POST',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * List image exemptions.
     *
     * List all of the exemptions for an image.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.resource - IBM Cloud Registry resource (namespace, namespace/repository,
     * namespace/repository:tag, or namespace/repository@sha256:hash).
     * @param {boolean} [params.includeScope] - Include scope on returned exemptions.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.Exemption[]>>}
     */
    VulnerabilityAdvisorV4.prototype.listImageExemptions = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['resource'];
        var _validParams = ['resource', 'includeScope', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var query = {
            'includeScope': _params.includeScope,
        };
        var path = {
            'resource': _params.resource,
        };
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'listImageExemptions');
        var parameters = {
            options: {
                url: '/va/api/v4/exemptions/image/{resource}',
                method: 'GET',
                qs: query,
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    /**
     * List exemptions for images.
     *
     * List the exemptions for the given list of images.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string[]} params.body - List of images.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<VulnerabilityAdvisorV4.Response<VulnerabilityAdvisorV4.JsonObject>>}
     */
    VulnerabilityAdvisorV4.prototype.listBulkImageExemptions = function (params) {
        var _params = __assign({}, params);
        var _requiredParams = ['body'];
        var _validParams = ['body', 'headers'];
        var _validationErrors = (0, ibm_cloud_sdk_core_1.validateParams)(_params, _requiredParams, _validParams);
        if (_validationErrors) {
            return Promise.reject(_validationErrors);
        }
        var body = _params.body;
        var sdkHeaders = (0, common_1.getSdkHeaders)(VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME, 'v4', 'listBulkImageExemptions');
        var parameters = {
            options: {
                url: '/va/api/v4/exemptions/images',
                method: 'POST',
                body: body,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Account': this.account,
                    'Accept-Language': this.acceptLanguage,
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    VulnerabilityAdvisorV4.DEFAULT_SERVICE_URL = 'https://icr.io';
    VulnerabilityAdvisorV4.DEFAULT_SERVICE_NAME = 'vulnerability_advisor';
    VulnerabilityAdvisorV4._regionalEndpoints = new Map([
        ['global', 'https://icr.io'],
        ['us-south', 'https://us.icr.io'],
        ['uk-south', 'https://uk.icr.io'],
        ['eu-gb', 'https://uk.icr.io'],
        ['eu-central', 'https://de.icr.io'],
        ['eu-de', 'https://de.icr.io'],
        ['ap-north', 'https://jp.icr.io'],
        ['jp-tok', 'https://jp.icr.io'],
        ['ap-south', 'https://au.icr.io'],
        ['au-syd', 'https://au.icr.io'],
        ['jp-osa', 'https://jp2.icr.io'],
        ['ca-tor', 'https://ca.icr.io'],
        ['br-sao', 'https://br.icr.io'], // br-sao
    ]);
    return VulnerabilityAdvisorV4;
}(ibm_cloud_sdk_core_1.BaseService));
module.exports = VulnerabilityAdvisorV4;
//# sourceMappingURL=v4.js.map